from unittest.mock import patch

from odoo import http
from odoo.tools import mute_logger
from odoo.tests import HttpCase, tagged, new_test_user
from odoo.addons.openerp_enterprise.tests.test_subscription import SubscriptionCommon

@tagged('post_install', '-at_install')
class TestFrenchCertification(SubscriptionCommon, HttpCase):
    quotation_template = 'openerp_enterprise.custom_template_odoo_yearly'

    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        # Set customer in France and create it's portal user
        cls.customer.write({
            'name': 'Cust Omer',
            'country_id': cls.env.ref('base.fr'),
        })
        cls.customer_user = new_test_user(
            cls.env, login='customer@example.net', groups='base.group_portal',
            name='French Customer', partner_id=cls.customer.id,
        )

    @patch('odoo.addons.openerp_enterprise.models.openerp_enterprise.ip2coordinates')
    def test_french_certification_download_portal(self, ip2coordinates_mock):
        # force database to be located in France
        ip2coordinates_mock.return_value = {'country_code': 'FR', 'city': 'Unlocalized'}

        self.main_subscription.client_order_ref = 'M230000FR0001'

        database = self.create_database()
        self.send_ping(database.db_uuid, {}, payload_update={
            'dbname': 'test_french_certification',
            'enterprise_code': 'M230000FR0001',
            'apps': ['mail', 'account'],
            'version': '16.0+e',
        })
        self.start_tour("/my/subscription", 'french_certification_download_portal', login=self.customer_user.login)

    @mute_logger('odoo.http')
    @patch('odoo.addons.openerp_enterprise.models.openerp_enterprise.ip2coordinates')
    def test_french_certification_download_public(self, ip2coordinates_mock):
        # force database to be located in France
        ip2coordinates_mock.return_value = {'country_code': 'FR', 'city': 'Unlocalized'}

        self.main_subscription.client_order_ref = 'M230000FR0001'

        database1 = self.create_database()
        self.send_ping(database1.db_uuid, {}, payload_update={
            'dbname': 'test_french_certification',
            'apps': ['mail', 'account_invoicing'],
            'version': '11.0+e',
        })
        database2 = self.create_database()
        self.send_ping(database2.db_uuid, {}, payload_update={
            'dbname': 'test_french_certification_no_accounting',
            'apps': ['mail', 'contacts'],
            'version': '16.0+e',
        })

        database3 = self.create_database()
        self.send_ping(database3.db_uuid, {}, payload_update={
            'dbname': 'test_french_certification_obsolete',
            'apps': ['mail', 'contacts'],
            'version': '8.0',
        })

        (database1 | database2 | database3).subscription_id = self.main_subscription

        self.start_tour("/my/contract/french-certification", 'french_certification_download_public')

    @patch('odoo.addons.openerp_enterprise.models.openerp_enterprise.ip2coordinates')
    def test_french_certification_pdf(self, ip2coordinates_mock):
        ip2coordinates_mock.return_value = {'country_code': 'FR', 'city': 'Unlocalized'}

        self.main_subscription.client_order_ref = 'M230000FR0001'

        database = self.create_database()
        self.send_ping(database.db_uuid, {}, payload_update={
            'dbname': 'test_french_certification',
            'enterprise_code': 'M230000FR0001',
            'apps': ['mail', 'account'],
            'version': '16.0+e',
        })

        self.authenticate(None, None)  # auth as public user (needed to compute csrf_token)
        resp = self.url_open('/odoo-enterprise/submit-fr-certification', data={
            'contract_nb': 'M230000FR0001',
            'db_uuid': database.db_uuid,
            'username': 'Cust Omer',
            'company_name': 'My French Company',
            'csrf_token': http.Request.csrf_token(self),
        }, timeout=3600)
        self.assertEqual(resp.status_code, 200)
        self.assertEqual(resp.headers['Content-Type'], 'application/pdf')
